Learn R Programming

snowplowtcomodel (version 0.1)

snowplowCostByMonth: Calculate the total Amazon costs associated with running Snowplow X months ahead

Description

Calculate the total Amazon costs associated with running Snowplow X months ahead

Usage

snowplowCostByMonth(uniquesPerMonth, eventsPerMonth, runsPerDay, storageDatabase, numberOfMonths, edgeLocations)

Arguments

uniquesPerMonth
number of unique visitors to website(s) per month
eventsPerMonth
number of events per month tracked
runsPerDay
number of times per day that enrichment process is run (generally 1-24)
numberOfMonths
number of months ahead that the model should project costs (e.g. 12 or 36)
edgeLocations
The number of different locations in Amazon's Cloudfront network that each generate an independent log when hit. We believe this number is between 10000 and 100000, but are not sure. (This has an impact on S3 costs)